define puppet_enterprise::trapperkeeper::classifier (
  $container              = $title,
  $user                   = "pe-${title}",
  $group                  = "pe-${title}",
  $database_host          = 'localhost',
  $database_port          = $puppet_enterprise::params::database_port,
  $database_name          = $puppet_enterprise::params::classifier_database_name,
  $database_user          = $puppet_enterprise::params::classifier_database_user,
  $database_password      = $puppet_enterprise::params::classifier_database_password,
  $database_properties    = '',
  $master_host            = undef,
  $client_certname        = $puppet_enterprise::params::classifier_client_certname,
  $localcacert            = $puppet_enterprise::params::localcacert,
  $synchronization_period = $puppet_enterprise::params::classifier_synchronization_period,
  $prune_days_threshold   = $puppet_enterprise::params::classifier_prune_threshold,
) {
  $cert_dir = "/opt/puppet/share/${container}/certs"
  $client_ssl_key  = "${cert_dir}/${client_certname}.private_key.pem"
  $client_ssl_cert = "${cert_dir}/${client_certname}.cert.pem"
  File {
    owner => $user,
    group => $group,
    mode  => '0640',
  }
  # Uses
  #   $master_host
  #   $client_ssl_key
  #   $client_ssl_cert
  #   $localcacert
  #   $synchronization_period
  #   $prune_days_threshold
  file { "/etc/puppetlabs/${container}/conf.d/classifier.conf":
    content => template('puppet_enterprise/trapperkeeper/classifier/classifier.conf.erb'),
  }

  unless pe_empty($database_password) {
    # Uses
    #   $database_host
    #   $database_port
    #   $database_name
    #   $database_user
    #   $database_password
    #   $database_properties
    file { "/etc/puppetlabs/${container}/conf.d/classifier-database.conf":
      content => template('puppet_enterprise/trapperkeeper/classifier/classifier-database.conf.erb'),
    }
  }


  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:classifier classifier-service" :
    container => $container,
    namespace => 'puppetlabs.classifier.main',
    service   => 'classifier-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:classifier activity-reporting-service" :
    container => $container,
    namespace => 'puppetlabs.activity.services',
    service   => 'activity-reporting-service',
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:classifier jetty9-service" :
    container => $container,
    namespace => 'puppetlabs.trapperkeeper.services.webserver.jetty9-service',
    service   => 'jetty9-service',
  }

}
